Index: trunk/ippTools/src/camtool.c
===================================================================
--- trunk/ippTools/src/camtool.c	(revision 25851)
+++ trunk/ippTools/src/camtool.c	(revision 25935)
@@ -109,6 +109,6 @@
     psMetadata *where = psMetadataAlloc();
     pxcamGetSearchArgs (config, where);
-    pxAddLabelSearchArgs (config, where, "-label", "camRun.label", "==");
-    PXOPT_COPY_STR(config->args, where, "-reduction", "camRun.reduction", "==");
+    pxAddLabelSearchArgs (config, where, "-label", "chipRun.label", "=="); // define using chipRun label
+    PXOPT_COPY_STR(config->args, where, "-reduction", "chipRun.reduction", "==");
 
     if (!psListLength(where->list) &&
@@ -199,11 +199,11 @@
     }
 
     // loop over our list of camRun rows
     for (long i = 0; i < psArrayLength(output); i++) {
         psMetadata *md = output->data[i];
 
-        camRunRow *row = camRunObjectFromMetadata(md);
+        chipRunRow *row = chipRunObjectFromMetadata(md);
         if (!row) {
-            psError(PS_ERR_UNKNOWN, false, "failed to convert metadata into camRun");
+            psError(PS_ERR_UNKNOWN, false, "failed to convert metadata into chipRun");
             psFree(output);
             return false;
@@ -199,11 +199,11 @@
     }
 
-    // loop over our list of camRun rows
+    // loop over our list of chipRun rows
     for (long i = 0; i < psArrayLength(output); i++) {
         psMetadata *md = output->data[i];
